@@ -13,7 +13,7 @@ __all__ = ['TaskContractor']
 class TaskContractor(Contractor):
     """A contractor to handle task related ones."""
 
-    _URL = 'http://alphamed-fed-service:9080/fed-service/api/v1'
+    _URL = 'http://federated-service:9080/fed-service/api/v1'
 
     _TITLE_FINISH = 'TaskFinish'
 
