@@ -139,7 +139,7 @@ class TaskMessageEventFactory(ContractEventFactory):
 class TaskMessageContractor(Contractor):
     """公共合约."""
 
-    _URL = 'http://alphamed-fed-service:9080/fed-service/api/v1/message'
+    _URL = 'http://federated-service:9080/fed-service/api/v1/message'
 
     _TASK_INSIDE = 'TaskInside'
     _TASK_FINISH = 'TaskFinish'
