@@ -17,8 +17,8 @@ from Crypto.PublicKey import RSA
 from Crypto.Random import get_random_bytes
 
 from .. import logger
-from ..contractor import (AcceptSendingDataEvent, DenySendingDataEvent,
-                          TaskMessageContractor)
+from ..contractor import (AcceptSendingDataEvent, ApplySendingDataEvent,
+                          DenySendingDataEvent, TaskMessageContractor)
 from ..utils import retry
 from . import data_channel_pb2, data_channel_pb2_grpc
 
@@ -52,16 +52,12 @@ class DataChannel(ABC):
         ...
 
     @abstractmethod
-    def receive_stream(self, session_id: str, source: str, sender_key: bytes) -> bytes:
+    def receive_stream(self, apply_event: ApplySendingDataEvent) -> bytes:
         """Receive data stream from a sender.
 
         :args
-            :session_id
-                the session id of this data transmission
-            :source
-                the data sender
-            :sender_key
-                the public key of the sender
+            :apply_event
+                the ApplySendingDataEvent object of this data transmission
         """
         ...
 
@@ -282,7 +278,7 @@ class GRPCDataChannel(DataChannel):
             logger.exception(err)
             raise err
 
-    def receive_stream(self, session_id: str, source: str, sender_key: bytes) -> bytes:
+    def receive_stream(self, apply_event: ApplySendingDataEvent) -> bytes:
         class GRPCDataChannelService:
             """GRPC Service Implementation."""
 
@@ -308,17 +304,17 @@ class GRPCDataChannel(DataChannel):
                 self._stop_event.set()
                 return data_channel_pb2.SendStreamResponse(received_len=len(data))
 
-        assert session_id, 'must specify the session_id'
-        assert source, 'must specify the source'
-        assert sender_key, 'must specify the public key of the sender'
+        assert apply_event, 'must specify the apply event to exact infomation.'
 
         if not self._is_ready_for_receiving():
-            self.contractor.deny_sending_data(session_id=session_id)
+            self.contractor.deny_sending_data(session_id=apply_event.session_id)
 
         # prepare and hand-shake
-        port, private_key = self._prepare_for_connecting(session_id=session_id,
-                                                         source=source,
-                                                         sender_key=sender_key)
+        port, private_key = self._prepare_for_connecting(
+            session_id=apply_event.session_id,
+            source=apply_event.source,
+            sender_key=apply_event.public_key
+        )
         logger.debug(f'port {port} is picked up')
 
         # setup listening server
@@ -326,7 +322,7 @@ class GRPCDataChannel(DataChannel):
         with TemporaryFile() as fp:
             server = grpc.server(ThreadPoolExecutor(max_workers=1))
             data_channel_pb2_grpc.add_GRPCDataChannelServicer_to_server(
-                servicer=GRPCDataChannelService(session_id=session_id,
+                servicer=GRPCDataChannelService(session_id=apply_event.session_id,
                                                 fp=fp,
                                                 stop_event=stop_event),
                 server=server
