@@ -623,13 +623,18 @@ def get_scheduler(mode: str = VANILLA) -> FedAvgScheduler:
                                calculation_timeout=120)
 
     elif mode == FED_IRM:
-        scheduler = DemoFedIRM(min_clients=2,
-                               max_clients=3,
-                               name='demo_task',
-                               max_rounds=50,
-                               log_rounds=5,
-                               calculation_timeout=3600,
-                               data_channel_timeout=(600, 200))
+        scheduler = DemoFedIRM(
+            min_clients=3,
+            max_clients=3,
+            root_path=os.path.join(CURRENT_DIR, 'gtr21/ISIN-2018/train_image_224'),
+            csv_file_train=os.path.join(CURRENT_DIR, 'train.csv'),
+            csv_file_test=os.path.join(CURRENT_DIR, 'test.csv'),
+            name='demo_Fed_IRM',
+            max_rounds=50,
+            log_rounds=5,
+            calculation_timeout=3600,
+            data_channel_timeout=(600, 200)
+        )
 
     with open(pickle_file, 'w+b') as pf:
         pickle.dump(scheduler, pf)
