@@ -242,11 +242,7 @@ class RSAPSIInitiatorScheduler(PSIInitiatorScheduler):
         self._contractor.notify_ready_for_signed_ids(initiator=self.initiator_id)
         for _event in self._contractor.contract_events():
             if isinstance(_event, SendingSignedIdsEvent):
-                signed_ids_stream = self._data_channel.receive_stream(
-                    session_id=_event.session_id,
-                    source=_event.source,
-                    sender_key=_event.public_key
-                )
+                signed_ids_stream = self._data_channel.receive_stream(_event)
                 signed_ids = _SignedIdsInfo.from_bytes(signed_ids_stream)
                 self.coll_signed_ids_map[_event.source] = signed_ids
             if len(self.coll_signed_ids_map) == len(self.collaborator_ids):
@@ -329,11 +325,7 @@ class RSAPSICollaboratorScheduler(PSICollaboratorScheduler):
         """Wait for blind ids to sign."""
         for _event in self._contractor.contract_events():
             if isinstance(_event, SendingBlindIdsEvent):
-                data_stream = self._data_channel.receive_stream(
-                    session_id=_event.session_id,
-                    source=_event.source,
-                    sender_key=_event.public_key
-                )
+                data_stream = self._data_channel.receive_stream(_event)
                 blind_ids = json.loads(data_stream.decode(encoding=_ENCODING))
                 return blind_ids
 
@@ -354,11 +346,7 @@ class RSAPSICollaboratorScheduler(PSICollaboratorScheduler):
         """Wait for receiving intersection result."""
         for _event in self._contractor.contract_events():
             if isinstance(_event, DistributingIntersectionEvent):
-                intersection_stream = self._data_channel.receive_stream(
-                    session_id=_event.session_id,
-                    source=_event.source,
-                    sender_key=_event.public_key
-                )
+                intersection_stream = self._data_channel.receive_stream(_event)
                 _intersection = json.loads(intersection_stream.decode(encoding=_ENCODING))
                 self.intersection = set(self._coll.signed_to_raw(_signed_id)
                                         for _signed_id in _intersection)
